==> haskell-wl-pprint-annotated-0.1.0.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.1
id: wl-pprint-annotated-0.1.0.1-Jvrz637WhbREZ6uQv8K112
key: wl-pprint-annotated-0.1.0.1-Jvrz637WhbREZ6uQv8K112
license: BSD-3-Clause
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
author: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.
category: Text
abi: d8f211adbd94b16899af757cfdcc1be0
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.WL
hidden-modules: Paths_wl_pprint_annotated
import-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-annotated-0.1.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/wl-pprint-annotated-0.1.0.1
hs-libraries: HSwl-pprint-annotated-0.1.0.1-Jvrz637WhbREZ6uQv8K112
depends:
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wl-pprint-annotated-0.1.0.1-12-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-wl-pprint-annotated.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: wl-pprint-annotated
version: 0.1.0.1
id: wl-pprint-annotated-0.1.0.1-9I0DBgJnavb4LgB5oJelx0
key: wl-pprint-annotated-0.1.0.1-9I0DBgJnavb4LgB5oJelx0
license: BSD-3-Clause
copyright: 2011-2012 Edward A. Kmett, 2000 Daan Leijen
maintainer: Daniel Mendler <mail@daniel-mendler.de>
author: Daniel Mendler <mail@daniel-mendler.de>
stability: experimental
homepage: https://github.com/minad/wl-pprint-annotated#readme
synopsis: Pretty printer with annotation support
description:
    Wadler/Leijen pretty printer with support for annotations and modernized API. Annotations are useful for coloring. See wl-pprint-console.
category: Text
abi: 4c4a08c6b52362db96f0914a8f26f607
exposed: True
exposed-modules:
    Text.PrettyPrint.Annotated.WL
hidden-modules: Paths_wl_pprint_annotated
import-dirs: /usr/lib/ghc-8.6.4/site-local/wl-pprint-annotated-0.1.0.1
library-dirs: /usr/lib/ghc-8.6.4/site-local/wl-pprint-annotated-0.1.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/wl-pprint-annotated-0.1.0.1
hs-libraries: HSwl-pprint-annotated-0.1.0.1-9I0DBgJnavb4LgB5oJelx0
depends:
    base-4.12.0.0 containers-0.6.0.1 deepseq-1.4.4.0 text-1.2.3.1
haddock-interfaces: /usr/share/doc/haskell-wl-pprint-annotated/html/wl-pprint-annotated.haddock
haddock-html: /usr/share/doc/haskell-wl-pprint-annotated/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
